Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(608)

Unified Diff: ppapi/c/private/ppp_content_decryptor_private.h

Issue 11087044: Generalize Pepper CDM API decrypt and decode. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ppapi/c/private/ppp_content_decryptor_private.h
diff --git a/ppapi/c/private/ppp_content_decryptor_private.h b/ppapi/c/private/ppp_content_decryptor_private.h
index 4c43b2799ef1148163b597442bc0d6133eb18ed0..066561dee3e46a07c52dcfd6ed74012081885534 100644
--- a/ppapi/c/private/ppp_content_decryptor_private.h
+++ b/ppapi/c/private/ppp_content_decryptor_private.h
@@ -4,7 +4,7 @@
*/
/* From private/ppp_content_decryptor_private.idl,
- * modified Mon Oct 01 20:27:29 2012.
+ * modified Tue Oct 09 22:39:32 2012.
*/
#ifndef PPAPI_C_PRIVATE_PPP_CONTENT_DECRYPTOR_PRIVATE_H_
@@ -114,23 +114,23 @@ struct PPP_ContentDecryptor_Private_0_2 {
PP_Resource encrypted_block,
const struct PP_EncryptedBlockInfo* encrypted_block_info);
/**
* Decrypts encrypted_video_frame, decodes it, and returns the unencrypted
* uncompressed (decoded) video frame to the browser via the
* <code>DeliverFrame()</code> method on the
* <code>PPB_ContentDecryptor_Private</code> interface.
*
* @param[in] encrypted_video_frame A <code>PP_Resource</code> corresponding
* to a <code>PPB_Buffer_Dev</code> resource that contains an encrypted video
* frame.
*
* @param[in] encrypted_video_frame_info A
* <code>PP_EncryptedVideoFrameInfo</code> that contains all information
* needed to decrypt and decode <code>encrypted_video_frame</code>.
*/
- void (*DecryptAndDecodeFrame)(
+ void (*DecryptAndDecode)(
PP_Instance instance,
- PP_Resource encrypted_video_frame,
- const struct PP_EncryptedVideoFrameInfo* encrypted_video_frame_info);
+ PP_Resource encrypted_buffer,
+ const struct PP_EncryptedMediaInfo* encrypted_media_info);
};
typedef struct PPP_ContentDecryptor_Private_0_2 PPP_ContentDecryptor_Private;
@@ -114,23 +114,23 @@ struct PPP_ContentDecryptor_Private_0_2 {
const struct PP_EncryptedBlockInfo* encrypted_block_info);
/**
- * Decrypts encrypted_video_frame, decodes it, and returns the unencrypted
- * uncompressed (decoded) video frame to the browser via the
- * <code>DeliverFrame()</code> method on the
+ * Decrypts encrypted_buffer, decodes it, and returns the unencrypted
+ * uncompressed (decoded) data to the browser via the
+ * <code>DeliverFrame()</code> or <code>DeliverSamples()</code> method on the
* <code>PPB_ContentDecryptor_Private</code> interface.
*
@@ -114,23 +114,23 @@ struct PPP_ContentDecryptor_Private_0_2 {
* frame.
*
- * @param[in] encrypted_video_frame_info A
- * <code>PP_EncryptedVideoFrameInfo</code> that contains all information
- * needed to decrypt and decode <code>encrypted_video_frame</code>.
+ * @param[in] encrypted_media_info A <code>PP_EncryptedMediaInfo</code> that
+ * contains all information needed to decrypt and decode
+ * <code>encrypted_buffer</code>.
*/

Powered by Google App Engine
This is Rietveld 408576698